@@ -16,7 +16,7 @@ from math import floor
 from itertools import chain, product, cycle, repeat, starmap
 import matplotlib as mpl
 import six
-from psyplot.utils import _TempBool
+from psyplot.utils import _temp_bool_prop
 from psyplot.compat.pycompat import map, range, filter, OrderedDict
 from psyplot_gui.compat.qtcompat import (
     QWidget, QComboBox, QHBoxLayout, QVBoxLayout, QFileDialog, QToolButton,
@@ -25,7 +25,8 @@ from psyplot_gui.compat.qtcompat import (
     QTableWidget, QTableWidgetItem, QGridLayout, QIntValidator, QMenu, QAction,
     QInputDialog, QTabWidget, QDoubleValidator, QGraphicsScene, asstring,
     QGraphicsRectItem, QGraphicsView, QDialog, QDialogButtonBox, QSplitter)
-from psyplot_gui.common import get_icon, ListValidator, PyErrorMessage
+from psyplot_gui.common import (get_icon, ListValidator, PyErrorMessage,
+                                LoadFromConsoleButton)
 from psyplot_gui.preferences import RcParamsTree
 import psyplot.project as psy
 
@@ -41,8 +42,8 @@ class CoordComboBox(QComboBox):
     emitted when the popup is about to be closed because the user clicked on a
     value"""
 
-    close_popups = _TempBool(True)
-    use_coords = _TempBool(False)
+    close_popups = _temp_bool_prop('close_popups', default=True)
+    use_coords = _temp_bool_prop('use_coords', default=False)
     leftclick = QtCore.pyqtSignal(QComboBox)
 
     def __init__(self, ds_func, dim, parent=None):
@@ -324,12 +325,6 @@ class CoordsTable(QTableWidget):
             self.setHorizontalHeaderItem(i, header_item)
             self.setCellWidget(0, i, CoordComboBox(self.get_ds, dim))
 
-    def reset_comboboxes(self):
-        """Clear all comboboxes"""
-        for cb in self.combo_boxes:
-            cb.clear()
-            cb._is_empty = True
-
     def sizeHint(self):
         """Reimplemented to adjust the heigth based upon the header and the
         first row"""
@@ -548,8 +543,16 @@ class ArrayTable(DragDropTable):
         """The names that are currently in use"""
         if self.prefer_list:
             return []
+        arr_col = self.arr_col
         return [asstring(item.text()) for item in filter(None, map(
-            lambda i: self.item(i, 1), range(self.rowCount())))]
+            lambda i: self.item(i, arr_col), range(self.rowCount())))]
+
+    @property
+    def vnames(self):
+        """The list of variable names per array"""
+        var_col = self.var_col
+        return [self.item(i, var_col).text().split(';;')
+                for i in range(self.rowCount())]
 
     @property
     def arr_names_dict(self):
@@ -557,8 +560,9 @@ class ArrayTable(DragDropTable):
         `arr_names` parameter in the
         :meth:`psyplot.data.ArrayList.from_dataset` method """
         ret = OrderedDict()
+        arr_col = self.arr_col
         for irow in range(self.rowCount()):
-            arr_name = asstring(self.item(irow, 1).text())
+            arr_name = asstring(self.item(irow, arr_col).text())
             if self.plot_method and self.plot_method._prefer_list:
                 d = ret.setdefault(arr_name, defaultdict(list))
                 d['name'].append(self._get_variables(irow))
@@ -1148,7 +1152,9 @@ class SubplotCreator(QWidget):
         # yes, return it
         for ax in fig.axes:
             ss = ax.get_subplotspec()
-            if ss.num1 == num1 and ss.num2 == num2:
+            if ss.num1 == num1 and (
+                    ss.num2 == num2 or (ss.num2 is None and num1 == num2) or
+                    (num2 is None and ss.num2 == num1)):
                 gs = ss.get_gridspec()
                 if gs.get_geometry() == (rows, cols):
                     return ax
@@ -1493,7 +1499,10 @@ class AxesSelector(QWidget):
 
     def get_picked_ax(self, event):
         """Function to be called when an axes is picked"""
-        ax = event.artist.get_axes()
+        try:
+            ax = event.artist.axes
+        except AttributeError:
+            ax = event.artist.get_axes()
         text = self.result_label.text()
         if text:
             text += ';;'
@@ -1620,9 +1629,8 @@ class PlotCreator(QDialog):
     #: Tooltip for not making a plot
     NO_PM_TT = 'Choose a plot method (or choose none to only extract the data)'
 
-    def __init__(self, get_obj=None, *args, **kwargs):
+    def __init__(self, *args, **kwargs):
         self.help_explorer = kwargs.pop('help_explorer', None)
-        self.get_obj = get_obj
         super(PlotCreator, self).__init__(*args, **kwargs)
         self.setAttribute(Qt.WA_DeleteOnClose)
         self.setWindowTitle('Create plots')
@@ -1643,8 +1651,7 @@ class PlotCreator(QDialog):
         self.bt_open_file = QToolButton(parent=w)
         self.bt_open_file.setIcon(QIcon(get_icon('run_arrow.png')))
         self.bt_open_file.setToolTip('Open a new dataset from the hard disk')
-        self.bt_get_ds = QToolButton(parent=w)
-        self.bt_get_ds.setIcon(QIcon(get_icon('console-go.png')))
+        self.bt_get_ds = LoadFromConsoleButton(xarray.Dataset, parent=w)
         self.bt_get_ds.setToolTip(
             'Use a dataset already defined in the console')
 
@@ -1664,6 +1671,12 @@ class PlotCreator(QDialog):
         self.array_table = ArrayTable(self.get_ds, parent=w)
         self.array_table.setup_from_ds(plot_method=self.pm_combo.currentText())
 
+        self.cbox_load = QCheckBox('load')
+        self.cbox_load.setToolTip(
+            'Load the selected data arrays into memory when clicking on '
+            '<em>Ok</em>. Note that this might cause problems for large '
+            'arrays!')
+
         self.cbox_close_popups = QCheckBox('close dropdowns', w)
         self.cbox_close_popups.setChecked(True)
         self.cbox_close_popups.setToolTip(
@@ -1690,7 +1703,7 @@ class PlotCreator(QDialog):
         self.rows_axis_label = QLabel('No. of rows', w)
         self.rows_axis_edit = QLineEdit(w)
         self.rows_axis_edit.setText('1')
-        self.cols_axis_label = QLabel('No. of columns', w)
+        self.cols_axis_label = QLabel('No. sof columns', w)
         self.cols_axis_edit = QLineEdit(w)
         self.cols_axis_edit.setText('1')
         self.max_axis_label = QLabel('No. of axes per figure', w)
@@ -1727,7 +1740,7 @@ class PlotCreator(QDialog):
 
         # ----------------- dataset combo connections ------------------------
         self.bt_open_file.clicked.connect(lambda: self.open_dataset())
-        self.bt_get_ds.clicked.connect(lambda: self.get_ds_from_shell())
+        self.bt_get_ds.object_loaded.connect(self.add_new_ds)
         self.ds_combo.currentIndexChanged[int].connect(self.set_ds)
 
         self.ds_combo.currentIndexChanged[int].connect(
@@ -1748,10 +1761,8 @@ class PlotCreator(QDialog):
         self.pm_combo.currentIndexChanged[str].connect(self.fill_fmt_tree)
 
         # --------------------- Combo box connections -------------------------
-        self.cbox_close_popups.clicked.connect(CoordComboBox.close_popups)
-        self.cbox_use_coords.clicked.connect(CoordComboBox.use_coords)
-        self.cbox_use_coords.clicked.connect(
-            self.coords_table.reset_comboboxes)
+        self.cbox_close_popups.clicked.connect(self.toggle_close_popups)
+        self.cbox_use_coords.clicked.connect(self.reset_comboboxes)
         # connect leftclick of combo boxes to create new arrays or update the
         # selected
         self.connect_combo_boxes()
@@ -1808,6 +1819,7 @@ class PlotCreator(QDialog):
 
         self.tree_box = QHBoxLayout()
         self.tree_box.addStretch(0)
+        self.tree_box.addWidget(self.cbox_load)
         self.tree_box.addWidget(self.cbox_close_popups)
         self.tree_box.addWidget(self.cbox_use_coords)
         self.tree_box.addWidget(self.bt_remove_all)
@@ -1855,6 +1867,20 @@ class PlotCreator(QDialog):
         self.setLayout(hbox)
         self.fill_fmt_tree(self.pm_combo.currentText())
 
+    def toggle_close_popups(self):
+        """Change the automatic closing of popups"""
+        close_popups = self.cbox_close_popups.isChecked()
+        for cb in self.coords_table.combo_boxes:
+            cb.close_popups = close_popups
+
+    def reset_comboboxes(self):
+        """Clear all comboboxes"""
+        use_coords = self.cbox_use_coords.isChecked()
+        for cb in self.coords_table.combo_boxes:
+            cb.use_coords = use_coords
+            cb.clear()
+            cb._is_empty = True
+
     def fill_fmt_tree(self, pm):
         self.fmt_tree.clear()
         if not pm:
@@ -1945,8 +1971,9 @@ class PlotCreator(QDialog):
             kwargs = {}
         fig_nums = plt.get_fignums()[:]
         try:
-            pm(self.ds, arr_names=names, **kwargs)
-        except:
+            pm(self.ds, arr_names=names, load=self.cbox_load.isChecked(),
+               **kwargs)
+        except Exception:
             for num in set(plt.get_fignums()).difference(fig_nums):
                 plt.close(num)
             self.error_msg.showTraceback('<b>Failed to create the plots!</b>')
@@ -1957,6 +1984,14 @@ class PlotCreator(QDialog):
 
     def open_dataset(self, fnames=None, *args, **kwargs):
         """Opens a file dialog and the dataset that has been inserted"""
+
+        def open_ds():
+            if len(fnames) == 1:
+                kwargs.pop('concat_dim', None)
+                return psy.open_dataset(fnames[0], *args, **kwargs)
+            else:
+                return psy.open_mfdataset(fnames, *args, **kwargs)
+
         if fnames is None:
             fnames = QFileDialog.getOpenFileNames(
                 self, 'Open dataset', os.getcwd(),
@@ -1968,20 +2003,29 @@ class PlotCreator(QDialog):
                 fnames = fnames[0]
         if isinstance(fnames, xarray.Dataset):
             ds = fnames
+            self.add_new_ds('ds', ds)
         elif not fnames:
             return
-        try:
-            if len(fnames) == 1:
-                ds = psy.open_dataset(fnames[0], *args, **kwargs)
-            else:
-                ds = psy.open_mfdataset(fnames, *args, **kwargs)
-        except:
-            self.error_msg.showTraceback(
-                '<b>Could not open dataset %s</b>' % (fnames, ))
-            return
-        fnames_str = ', '.join(fnames)
-        self.ds_descs.insert(0, {'ds': ds, 'fname': fnames_str})
-        self.ds_combo.insertItem(0, 'New: ' + fnames_str)
+        else:
+            try:
+                ds = open_ds()
+            except Exception:
+                kwargs['decode_times'] = False
+                try:
+                    ds = open_ds()
+                except Exception:
+                    self.error_msg.showTraceback(
+                        '<b>Could not open dataset %s</b>' % (fnames, ))
+                    return
+            fnames_str = ', '.join(fnames)
+            self.add_new_ds(fnames_str, ds, fnames_str)
+
+    def add_new_ds(self, oname, ds, fname=None):
+        d = {'ds': ds}
+        if fname:
+            d['fname'] = fname
+        self.ds_descs.insert(0, d)
+        self.ds_combo.insertItem(0, 'New: ' + oname)
         self.ds_combo.setCurrentIndex(0)
 
     def set_ds(self, i):
@@ -2095,31 +2139,3 @@ class PlotCreator(QDialog):
             self.close()
         else:
             super(PlotCreator, self).keyPressEvent(e)
-
-    def get_ds_from_shell(self, oname=None):
-        """Open an input dialog and receive a dataset"""
-        if oname is None:
-            oname, ok = QInputDialog().getText(
-                self, 'Enter a variable name from the console', '')
-            if not ok:
-                return
-        if isinstance(oname, xarray.Dataset):
-            found, ds = True, oname
-            oname = 'ds'
-        else:
-            found, ds = self.get_obj(oname.strip())
-        if found:
-            if isinstance(ds, xarray.Dataset):
-                self.ds_descs.insert(0, {'ds': ds})
-                self.ds_combo.insertItem(0, 'New: ' + oname)
-                self.ds_combo.setCurrentIndex(0)
-            else:
-                self.error_msg.showMessage(
-                    'Object must be an instance of xarray.Dataset, not %s' % (
-                        type(ds)))
-        else:
-            if not oname.strip():
-                msg = 'The variable name must not be empty!'
-            else:
-                msg = 'Could not find object ' + oname
-            self.error_msg.showMessage(msg)
